# fitgrid: run linear models on stacks of epochs
[![Build Status](https://travis-ci.org/kutaslab/fitgrid.svg?branch=master)](https://travis-ci.org/kutaslab/fitgrid)
[![codecov](https://codecov.io/gh/kutaslab/fitgrid/branch/master/graph/badge.svg)](https://codecov.io/gh/kutaslab/fitgrid)
[![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gh/kutaslab/fitgrid/master?filepath=Demo.ipynb)

*Click the Binder badge above to run a demo notebook.*

# Documentation

Available [here](https://kutaslab.github.io/fitgrid).

# Installation

To install, clone this repository:

    git clone https://github.com/kutaslab/fitgrid

change directory and `pip install`:

    cd fitgrid
    pip install .

This will also install `fitgrid`'s dependencies (for a list, see
`requirements.txt`).

# Tests

To run the tests you can install `pytest`:

    pip install pytest

and inside the `fitgrid` directory run:

    pytest

In the future, `fitgrid` will be available on PyPi.
